@@ -6,9 +6,11 @@ from async_messages import get_messages
 class AsyncMiddleware(object):
 
     def process_response(self, request, response):
-        # Check for messages for this user and, if it exists,
-        # call the messages API with it
-        if hasattr(request, "session") and request.user.is_authenticated():
+        """
+        Check for messages for this user and, if it exists,
+        call the messages API with it
+        """
+        if hasattr(request, "session") and hasattr(request, "user") and request.user.is_authenticated():
             msgs = get_messages(request.user)
             if msgs:
                 for msg, level in msgs:
